@@ -1,7 +1,7 @@
 var monthNames = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
 
 $(document).ready(function() {
-    $(".relatize").relatizeDate();
+    $("abbr.timeago").timeago();
 });
 
 function showTooltip(x, y, contents) {
