@@ -1,66 +1,95 @@
-import re
-
+# -*- coding: utf-8 -*-
 from time import mktime
 
-from django.utils.translation import ugettext, ugettext_lazy as _
+from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Count
-from django.utils.translation import string_concat
+from django.utils.text import format_lazy
+from django.utils.translation import gettext
+from django.utils.translation import gettext_lazy as _
 
-from request import settings
-from request.models import Request
-
-# Calculate the verbose_name by converting from InitialCaps to "lowercase with spaces".
-get_verbose_name = lambda class_name: re.sub('(((?<=[a-z])[A-Z])|([A-Z](?![A-Z]|$)))', ' \\1', class_name).strip()
+from . import settings
+from .utils import get_verbose_name
 
 
 class Modules(object):
+    '''
+    Set of :class:`.Module`.
+    '''
     def load(self):
-        from django.utils.importlib import import_module
-        from django.core import exceptions
+        '''
+        Import and instanciate modules defined in
+        ``settings.TRAFFIC_MODULES``.
+        '''
+        from importlib import import_module
 
-        self._modules = []
-        for module_path in settings.REQUEST_TRAFFIC_MODULES:
+        self._modules = ()
+        for module_path in settings.TRAFFIC_MODULES:
             try:
                 dot = module_path.rindex('.')
             except ValueError:
-                raise exceptions.ImproperlyConfigured, '%s isn\'t a traffic module' % module_path
-            traffic_module, traffic_classname = module_path[:dot], module_path[dot + 1:]
+                raise ImproperlyConfigured('{0} isn\'t a traffic module'.format(module_path))
+            traffic_module = module_path[:dot]
+            traffic_classname = module_path[dot + 1:]
 
             try:
                 mod = import_module(traffic_module)
-            except ImportError, e:
-                raise exceptions.ImproperlyConfigured, 'Error importing module %s: "%s"' % (traffic_module, e)
+            except ImportError as err:
+                raise ImproperlyConfigured('Error importing module {0}: "{1}"'.format(traffic_module, err))
 
             try:
                 traffic_class = getattr(mod, traffic_classname)
             except AttributeError:
-                raise exceptions.ImproperlyConfigured, 'Traffic module "%s" does not define a "%s" class' % (traffic_module, traffic_classname)
+                raise ImproperlyConfigured('Traffic module "{0}" does not define a "{1}" class'.format(
+                    traffic_module,
+                    traffic_classname,
+                ))
 
-            self._modules.append(traffic_class())
+            self._modules += (traffic_class(),)
 
+    @property
     def modules(self):
+        '''
+        Get loaded modules, load them if isn't already made.
+        '''
         if not hasattr(self, '_modules'):
             self.load()
         return self._modules
-    modules = property(modules)
 
     def table(self, queries):
-        return [(module.verbose_name_plural, [module.count(qs) for qs in queries]) for module in self.modules]
+        '''
+        Get a list of modules' counters.
+        '''
+        return tuple([(
+            module.verbose_name_plural, [module.count(qs) for qs in queries]
+        ) for module in self.modules])
 
     def graph(self, days):
-        return [{'data':[(mktime(day.timetuple()) * 1000, module.count(qs)) for day, qs in days], 'label':ugettext(module.verbose_name_plural)} for module in self.modules]
+        '''
+        Get a list of modules' counters for all the given days.
+        '''
+        return tuple([{
+            'data': [(mktime(day.timetuple()) * 1000, module.count(qs)) for day, qs in days],
+            'label': str(gettext(module.verbose_name_plural)),
+        } for module in self.modules])
+
 
 modules = Modules()
 
 
 class Module(object):
+    '''
+    Base module class.
+    '''
     def __init__(self):
         self.module_name = self.__class__.__name__
 
         if not hasattr(self, 'verbose_name'):
-            self.verbose_name = _(get_verbose_name(self.module_name))
+            self.verbose_name = get_verbose_name(self.module_name)
         if not hasattr(self, 'verbose_name_plural'):
-            self.verbose_name_plural = string_concat(self.verbose_name, 's')
+            self.verbose_name_plural = format_lazy('{}{}', self.verbose_name, 's')
+
+    def count(self, qs):
+        raise NotImplementedError('"count" isn\'t defined.')
 
 
 class Ajax(Module):
@@ -131,7 +160,9 @@ class UniqueVisit(Module):
     verbose_name_plural = _('Unique Visits')
 
     def count(self, qs):
-        return qs.exclude(referer__startswith=settings.REQUEST_BASE_URL).count()
+        return qs.exclude(
+            referer__startswith=settings.BASE_URL,
+        ).count()
 
 
 class UniqueVisitor(Module):
